start

# XLIFF

XLIFF is the OASIS standard for translation. See http://www.oasis-open.org/committees/xliff/documents/xliff-specification.htm.

## Flavours

XLIFF also has documents that specify the conversion from various standard source documents and localisation formats.

- PO - For conformance to the po2xliff spec, see xliff2po.
  - Draft XLIFF 1.2 Representation Guide for Gettext PO
- HTML - not implemented
  - Draft XLIFF 1.2 Representation Guide for HTML
- Java (includes .properties and Java resource bundles) - not implemented
  - Draft XLIFF 1.2 Representation Guide for Java Resource Bundles
- ICU Resource Bundles - not officially being developed by XLIFF - Proposed representation guide

## Standard conformance

### Done

- File creation and parsing
- API can create multiple files in one XLIFF (some tools only read the first file)
- source-language attribute
- trans-unit with
  - note: addnote() and getnotes()
  - state
    - fuzzy: isfuzzy() and markfuzzy()
    - translated: marktranslated()
    - approved
    - needs-review-transaltion: isreview(), markreviewneeded()
  - id: setid()
  - context-group: createcontextgroup()
- context groups
- alt-trans

## XLIFF and other tools

Here is a small report on the XLIFF support by MS Windows programs.